@@ -1,8 +1,9 @@
 import time
 from functools import wraps
-
 import logging
 
+import numpy as np
+
 logger = logging.getLogger(__name__)
 
 
@@ -15,3 +16,11 @@ def debug_timer(func):
         logger.debug('%s needed: %f s' % (func.__name__, end - start))
         return result
     return wrapper
+
+
+def array_dump(name, arr):
+    """ A utility function for dumping numpy arrays to disk.
+        Used for manually creating test data in debugging mode.
+    """
+    with open(name + '.npy', 'wb') as f:
+        np.save(f, arr)
